PO Files — Translate Toolkit 1.13.0-rc1 documentation

# PO Files

PO files use the file format of the Gettext tools.

See also

Gettext manual

## Supported Features

- Headers

- Language header (since gettext version 0.17)

- Plural forms and plural form handling

- Message context

      msgctxt "noun"
      msgid "View"
      msgstr ""

- Normal comments

      # this is another comment

- Automatic comments

      #. comment extracted from the source code

- Source location comments

      #: sourcefile.xxx:35

- Typecomments

      #, fuzzy

- Msgidcomments, also known as KDE style comments as they are used by KDE for message disambiguation and comments to translators.

  Note

  Support for this is being phased out in favor of `msgctxt`.

      msgid "_: comment\n"
      "translation"

- Obsolete messages

      #~ msgid "Blah"
      #~ msgstr "Bleeh"

- Previous msgid

      #| msgid "previous message"

- Previous msgctxt

      #| msgctxt "previous context"